unit Frmprint;

(******************************************************************)
(*                                                                *)
(*  Please note that this sample program uses the component       *)
(*  TNumLab, which is not contained in this package. A shareware  *)
(*  version of TNumLab can be downloaded from the following URL:  *)
(*                                                                *)
(*  http://qspr03.tuwien.ac.at/lo/                                *)
(*    (look for the Delphi components page)                       *)
(*                                                                *)
(******************************************************************)


interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, RChart, StdCtrls, ExtCtrls, NumLab;

type
  TForm1 = class(TForm)
    RChart1: TRChart;
    Button1: TButton;
    Button2: TButton;
    SBScalF: TScrollBar;
    NLbScaleF: TNumLab;
    Label1: TLabel;
    Bevel1: TBevel;
    RChart2: TRChart;
    NLbPosX: TNumLab;
    NLbPosY: TNumLab;
    Bevel2: TBevel;
    Label2: TLabel;
    Label3: TLabel;
    Bevel3: TBevel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    PrintDialog1: TPrintDialog;
    procedure FormActivate(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure RChart2MouseMoveInChart(Sender: TObject; InChart: Boolean;
      shift: TShiftState; rMousePosX, rMousePosY: Double);
    procedure SBScalFChange(Sender: TObject);
    procedure RChart2Click(Sender: TObject);
    procedure FormMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
  private
    procedure ShowPageRect;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

uses
  printers;

var
  PrintPosX   : integer;              { position of printout }
  PrintPosY   : integer;
  PrintScaleF : double;         { scaling factor of printout }
  xpRes, ypRes: integer;                { printer resolution }
  xpSize,
  ypSize      : integer;                { printer paper size }


(************************************************************)
procedure TForm1.FormActivate(Sender: TObject);
(************************************************************)

var
  i : integer;

begin
RChart1.ClearGraf;
RChart1.MoveTo (0,0);
for i:=1 to 200 do
  RChart1.DrawTo (i, (1-exp(i*0.005))*sin(0.2*i)*sin(0.33*i));
RChart1.ShowGraf;
PrintPosX := 100;
PrintPosY := 100;
PrintScaleF := 1.0;
NLbScaleF.Value := 1.0;
SbScalF.Position := 0;
xpRes := GetDeviceCaps (Printer.Handle, LOGPIXELSX);
ypRes := GetDeviceCaps (Printer.Handle, LOGPIXELSY);
xpSize := GetDeviceCaps (Printer.Handle, HORZSIZE);
ypSize := GetDeviceCaps (Printer.Handle, VERTSIZE);
RChart2.SetRange (0, ypSize/25.4*ypRes, xpSize/25.4*xpRes, 0);
ShowPageRect;
end;

(************************************************************)
procedure TForm1.ShowPageRect;
(************************************************************)


begin
RChart2.ClearGraf;
RChart2.DataCOlor := clNavy;
RChart2.Rectangle (PrintPosX, PrintPosY,
                   PrintPosX+PrintScaleF*xpRes/Screen.PixelsPerInch*RChart1.Width,
                   PrintPosY+PrintScaleF*ypRes/Screen.PixelsPerInch*RChart1.Height);
RChart2.DataCOlor := clLime;
RChart2.Text ((2*PrintPosX+PrintScaleF*xpRes/Screen.PixelsPerInch*RChart1.Width)/2,
              (2*PrintPosY+PrintScaleF*ypRes/Screen.PixelsPerInch*RChart1.Height)/2,
              round(8*PrintScaleF), 'Chart');
RChart2.ShowGraf;
end;


(************************************************************)
procedure TForm1.Button1Click(Sender: TObject);
(************************************************************)

begin
close;
end;

(************************************************************)
procedure TForm1.Button2Click(Sender: TObject);
(************************************************************)

var
  astr : string;

begin
if PrintDialog1.Execute then
  begin
  Printer.BeginDoc;
  str (PrintScaleF:1:2, astr);
  Printer.Canvas.TextOut (100,40,'Position of image: x='+
                          IntToStr(PrintPosX)+'  y='+IntToStr(PrintPosY)+
                          '    Scaling factor: '+astr);
  RChart1.CopyToOpenPrinter (PrintPosX,PrintPosY, PrintScaleF, true);
  Printer.Canvas.TextOut (300,PrintPosY+20,'This line is just below the printed image');
  Printer.EndDoc;
  end;
end;

(************************************************************)
procedure TForm1.RChart2MouseMoveInChart(Sender: TObject;
          InChart: Boolean; shift: TShiftState;
          rMousePosX, rMousePosY: Double);
(************************************************************)

begin
NLbPosX.Empty := not Inchart;
NLbPosY.Empty := not Inchart;
NLbPosX.Value := rMousePosX;
NLbPosY.Value := rMousePosY;
if ssLeft in Shift then
  begin
  PrintPosX := round(RChart2.MousePosX);
  PrintPosY := round(RChart2.MousePosY);
  SHowPageRect;
  end;
end;

(************************************************************)
procedure TForm1.SBScalFChange(Sender: TObject);
(************************************************************)

begin
PrintScaleF := 1.0+(SBScalF.Position/100);
NLbScaleF.Value := PrintScaleF;
SHowPageRect;
end;

(************************************************************)
procedure TForm1.RChart2Click(Sender: TObject);
(************************************************************)

begin
PrintPosX := round(RChart2.MousePosX);
PrintPosY := round(RChart2.MousePosY);
SHowPageRect;
end;

(************************************************************)
procedure TForm1.FormMouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);
(************************************************************)

begin
SCreen.Cursor := crdefault;
NLbPosX.Empty := true;
NLbPosY.Empty := true;
end;

end.
